==> MIDITrail-Ver.1.2.2-iOS_src.zip: __MACOSX/MIDITrail/MIDITrail/Sources/YNBaseLib/._YNBaseLib.h <==
    Mac OS X            	   2        0                                   ATTR      0      L                       com.apple.TextEncoding           com.apple.lastuseddate#PS         -  com.apple.quarantine UTF-8;134217984|\Z    x^    q/0081;4f6e9512;Firefox;|org.mozilla.firefox      s  s   ]                                                                                                                                                                                                                                                  
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>AntiAliasMode</key>
	<integer>0</integer>
	<key>CaretMode</key>
	<true/>
	<key>CaretPoint X</key>
	<integer>0</integer>
	<key>CaretPoint Y</key>
	<integer>16</integer>
	<key>DocWrapMode</key>
	<integer>0</integer>
	<key>FilePath</key>
	<string>/Users/wada/Documents/Xcode Projects/MIDITrail/Sources/YNBaseLib/YNBaseLib.h</string>
	<key>IndentWidth</key>
	<integer>4</integer>
	<key>LetterCount</key>
	<integer>80</integer>
	<key>ModeName</key>
	<string>C</string>
	<key>PrintForm_FileFont</key>
	<integer>16384</integer>
	<key>PrintForm_FileFontName</key>
	<string>Osaka</string>
	<key>PrintForm_FileFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_FileFontSize</key>
	<real>9</real>
	<key>PrintForm_ForceWordWrap</key>
	<false/>
	<key>PrintForm_LineFont</key>
	<integer>16384</integer>
	<key>PrintForm_LineFontName</key>
	<string>Osaka</string>
	<key>PrintForm_LineFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_LineMargin</key>
	<integer>0</integer>
	<key>PrintForm_PageFont</key>
	<integer>16384</integer>
	<key>PrintForm_PageFontName</key>
	<string>Osaka</string>
	<key>PrintForm_PageFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_PageFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintFileName</key>
	<true/>
	<key>PrintForm_PrintFont</key>
	<integer>16384</integer>
	<key>PrintForm_PrintFontName</key>
	<string>Osaka</string>
	<key>PrintForm_PrintFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_PrintFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintLineNumber</key>
	<true/>
	<key>PrintForm_PrintPageNumber</key>
	<true/>
	<key>PrintForm_PrintSeparateLine</key>
	<true/>
	<key>PrintForm_UsePrintFont</key>
	<true/>
	<key>PrintForm_WrapMode</key>
	<integer>0</integer>
	<key>ReturnCode</key>
	<integer>2</integer>
	<key>SelectPoint X</key>
	<integer>0</integer>
	<key>SelectPoint Y</key>
	<integer>16</integer>
	<key>TabWidth</key>
	<integer>4</integer>
	<key>TextEncoding</key>
	<string>UTF-8</string>
	<key>TextFont</key>
	<integer>4</integer>
	<key>TextFontName</key>
	<string>Osaka−等幅</string>
	<key>TextFontNameUni</key>
	<string>default</string>
	<key>TextFontSize</key>
	<real>12</real>
	<key>WindowHeight</key>
	<integer>800</integer>
	<key>WindowPosition H</key>
	<integer>445</integer>
	<key>WindowPosition V</key>
	<integer>150</integer>
	<key>WindowWidth</key>
	<integer>640</integer>
	<key>WrapMode</key>
	<integer>0</integer>
	<key>WrapWithLetterCount</key>
	<false/>
	<key>WrapWithLetterCount LetterCount</key>
	<integer>78</integer>
</dict>
</plist>
                         `@  	@  	@  	@       oo                                    t      : =       z         rT               C            t      t        h  \         s  s   ]@     F MMKE   MMKP                
    mi Document Preference

==> MIDITrail-Ver.1.3.3-iOS_src.zip: __MACOSX/MIDITrail/MIDITrail/Sources/YNBaseLib/._YNBaseLib.h <==
    Mac OS X            	   2        0                                   ATTR      0      L                       com.apple.TextEncoding           com.apple.lastuseddate#PS         -  com.apple.quarantine UTF-8;134217984ф8_    ;غ%    q/0081;4f6e9512;Firefox;|org.mozilla.firefox      s  s   ]                                                                                                                                                                                                                                                  
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>AntiAliasMode</key>
	<integer>0</integer>
	<key>CaretMode</key>
	<true/>
	<key>CaretPoint X</key>
	<integer>0</integer>
	<key>CaretPoint Y</key>
	<integer>16</integer>
	<key>DocWrapMode</key>
	<integer>0</integer>
	<key>FilePath</key>
	<string>/Users/wada/Documents/Xcode Projects/MIDITrail/Sources/YNBaseLib/YNBaseLib.h</string>
	<key>IndentWidth</key>
	<integer>4</integer>
	<key>LetterCount</key>
	<integer>80</integer>
	<key>ModeName</key>
	<string>C</string>
	<key>PrintForm_FileFont</key>
	<integer>16384</integer>
	<key>PrintForm_FileFontName</key>
	<string>Osaka</string>
	<key>PrintForm_FileFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_FileFontSize</key>
	<real>9</real>
	<key>PrintForm_ForceWordWrap</key>
	<false/>
	<key>PrintForm_LineFont</key>
	<integer>16384</integer>
	<key>PrintForm_LineFontName</key>
	<string>Osaka</string>
	<key>PrintForm_LineFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_LineMargin</key>
	<integer>0</integer>
	<key>PrintForm_PageFont</key>
	<integer>16384</integer>
	<key>PrintForm_PageFontName</key>
	<string>Osaka</string>
	<key>PrintForm_PageFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_PageFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintFileName</key>
	<true/>
	<key>PrintForm_PrintFont</key>
	<integer>16384</integer>
	<key>PrintForm_PrintFontName</key>
	<string>Osaka</string>
	<key>PrintForm_PrintFontNameUni</key>
	<string>Osaka</string>
	<key>PrintForm_PrintFontSize</key>
	<real>9</real>
	<key>PrintForm_PrintLineNumber</key>
	<true/>
	<key>PrintForm_PrintPageNumber</key>
	<true/>
	<key>PrintForm_PrintSeparateLine</key>
	<true/>
	<key>PrintForm_UsePrintFont</key>
	<true/>
	<key>PrintForm_WrapMode</key>
	<integer>0</integer>
	<key>ReturnCode</key>
	<integer>2</integer>
	<key>SelectPoint X</key>
	<integer>0</integer>
	<key>SelectPoint Y</key>
	<integer>16</integer>
	<key>TabWidth</key>
	<integer>4</integer>
	<key>TextEncoding</key>
	<string>UTF-8</string>
	<key>TextFont</key>
	<integer>4</integer>
	<key>TextFontName</key>
	<string>Osaka−等幅</string>
	<key>TextFontNameUni</key>
	<string>default</string>
	<key>TextFontSize</key>
	<real>12</real>
	<key>WindowHeight</key>
	<integer>800</integer>
	<key>WindowPosition H</key>
	<integer>445</integer>
	<key>WindowPosition V</key>
	<integer>150</integer>
	<key>WindowWidth</key>
	<integer>640</integer>
	<key>WrapMode</key>
	<integer>0</integer>
	<key>WrapWithLetterCount</key>
	<false/>
	<key>WrapWithLetterCount LetterCount</key>
	<integer>78</integer>
</dict>
</plist>
                         `@  	@  	@  	@       oo                                    t      : =       z         rT               C            t      t        h  \         s  s   ]@     F MMKE   MMKP                
    mi Document Preference
